sbs.chi: Satorra-Bentler Scaled Chi-Squared Difference Test (Based on Chi-Squared Values)
Description
Takes chi-squared values from nested models estimated using maximum likelihood
with robust standard errors, model degrees of freedom, scaling correlation factors and returns:
(1) change in model chi-squared (2) change in model degrees of freedom and
(3) the probability of rejecting the null.
Usage
sbs.chi(chi0, chi1, df0, df1, c0, c1)
Arguments
chi0
chi-squared value for the more restrictive model
chi1
chi-squared value for the less restrictive model
df0
degrees of freedom for the more restrictive model (with more degrees of freedom)
df1
degrees of freedom for the less restrictive model (with fewer degrees of freedom)
c0
scaling correction factor for the more restrictive model
c1
scaling correction factor for the less restrictive model
Value
Change in model chi-squared, change in model degrees of freedom and the probability of rejecting the null